@@ -1,19 +1,25 @@
+from __future__ import annotations
+
+import logging
 from asyncio.coroutines import iscoroutinefunction
 from functools import wraps
 from importlib import import_module
-from typing import Any, Callable, Coroutine, Optional, overload
+from threading import local
+from typing import TYPE_CHECKING, Any, Callable, Coroutine, Final, overload
 
-from donald.types import TV, TVAsyncFn
+if TYPE_CHECKING:
+    from donald.types import TV, TVAsyncFn
 
 
-def import_obj(path: str, obj_name: Optional[str] = None) -> Any:
+def import_obj(path: str) -> Any:
     """Import an object from a string path."""
     module_path, _, obj_path = path.rpartition(".")
     try:
         module = import_module(module_path)
-        return getattr(module, obj_path)
     except (ImportError, AttributeError, ValueError) as exc:
         raise ImportError(f"Could not import {path!r}") from exc
+    else:
+        return getattr(module, obj_path)
 
 
 @overload
@@ -36,3 +42,25 @@ def to_coroutinefn(fn):
         return fn(*args, **kwargs)
 
     return corofn
+
+
+class DonaldError(RuntimeError):
+    """Donald error."""
+
+
+class ManagerNotReadyError(DonaldError):
+    """Manager is not ready."""
+
+
+class BackendNotReadyError(DonaldError):
+    """Backend is not ready."""
+
+
+class SchedulerNotReadyError(DonaldError):
+    """Scheduler is not ready."""
+
+
+logger: Final = logging.getLogger("donald")
+
+current_manager: Final = local()
+current_manager.value = None
